@@ -8,8 +8,8 @@ import psutil
 from loguru import logger
 
 from contaxy.config import settings
+from contaxy.managers.auth import AuthManager
 from contaxy.managers.deployment.utils import (
-    _ENV_VARIABLE_CONTAXY_SERVICE_URL,
     _MIN_MEMORY_DEFAULT_MB,
     DEFAULT_DEPLOYMENT_ACTION_ID,
     NO_LOGS_MESSAGE,
@@ -96,9 +96,15 @@ def map_container(
     parameters = transform_env_list(
         container.attrs.get("Config", {}).get("Env", [])
     )  # dict([x for x in [container_env.split("=") for container_env in container_envs]])
+    image_tags = container.image.tags
+    # Use the first image tag as name. If the image has no tags, use the id.
+    if len(image_tags) > 0:
+        container_image = image_tags[0]
+    else:
+        container_image = container.image.short_id
 
     return {
-        "container_image": container.image.tags[0],
+        "container_image": container_image,
         "command": " ".join(container.attrs.get("Args", [])),
         "compute": compute_resources,
         "metadata": mapped_labels.metadata,
@@ -411,24 +417,29 @@ def define_mounts(
     service_requirements: Optional[List[str]] = [],
 ) -> list:
     mounts = []
-    if service_requirements and "docker" in service_requirements:
-        # TODO: IMPORTANT mark container as having extended privileges so that on a higher level the platform
-        # can prevent that a non-admin creates a container with the Docker socket mounted
-        mounts.append(
-            docker.types.Mount(
-                target="/var/run/docker.sock", source="/var/run/docker.sock"
-            )
-        )
+    # if service_requirements and "docker" in service_requirements:
+    #     # TODO: IMPORTANT mark container as having extended privileges so that on a higher level the platform
+    #     # can prevent that a non-admin creates a container with the Docker socket mounted
+    #     mounts.append(
+    #         docker.types.Mount(
+    #             target="/var/run/docker.sock", source="/var/run/docker.sock"
+    #         )
+    #     )
 
     if (
         compute_resources.volume_path is not None
         and compute_resources.volume_path != ""
     ):
-        mount_type = "bind" if settings.HOST_DATA_ROOT_PATH is not None else "volume"
+        if settings.HOST_DATA_ROOT_PATH is None:
+            mount_type = "volume"
+            prefix = ""
+        else:
+            mount_type = "bind"
+            prefix = settings.HOST_DATA_ROOT_PATH
         mounts.append(
             docker.types.Mount(
                 target=str(compute_resources.volume_path),
-                source=f"{settings.HOST_DATA_ROOT_PATH}{get_volume_name(project_id, container_name)}",
+                source=f"{prefix}{get_volume_name(project_id, container_name)}",
                 labels={
                     Labels.NAMESPACE.value: settings.SYSTEM_NAMESPACE,
                     Labels.PROJECT_NAME.value: project_id,
@@ -444,6 +455,7 @@ def define_mounts(
 def create_container_config(
     service: Union[JobInput, ServiceInput],
     project_id: str,
+    auth_manager: AuthManager,
     user_id: Optional[str] = None,
 ) -> Dict[str, Any]:
     if service.display_name is None:
@@ -497,6 +509,7 @@ def create_container_config(
         **get_default_environment_variables(
             project_id=project_id,
             deployment_id=container_name,
+            auth_manager=auth_manager,
             endpoints=service.endpoints,
             compute_resources=compute_resources,
         ),
@@ -504,9 +517,7 @@ def create_container_config(
     environment = replace_templates(
         environment,
         get_template_mapping(
-            project_id=project_id,
-            user_id=user_id,
-            service_url=environment.get(_ENV_VARIABLE_CONTAXY_SERVICE_URL, ""),
+            project_id=project_id, user_id=user_id, environment=environment
         ),
     )
 
