@@ -4,8 +4,11 @@ from enum import Enum
 from typing import Any, Dict, List, Optional, Tuple
 
 from contaxy.config import settings
+from contaxy.managers.auth import AuthManager
+from contaxy.schema import AccessLevel, TokenType
+from contaxy.schema.auth import TokenPurpose
 from contaxy.schema.deployment import DeploymentCompute, DeploymentType
-from contaxy.utils import id_utils
+from contaxy.utils import auth_utils, id_utils
 
 DEFAULT_DEPLOYMENT_ACTION_ID = "default"
 NO_LOGS_MESSAGE = "No logs available."
@@ -19,7 +22,9 @@ _MIN_MEMORY_DEFAULT_MB = 100
 
 _ENV_VARIABLE_CONTAXY_BASE_URL = "CONTAXY_BASE_URL"
 _ENV_VARIABLE_CONTAXY_API_ENDPOINT = "CONTAXY_API_ENDPOINT"
+_ENV_VARIABLE_CONTAXY_API_TOKEN = "CONTAXY_API_TOKEN"
 _ENV_VARIABLE_CONTAXY_SERVICE_URL = "CONTAXY_SERVICE_URL"
+_ENV_VARIABLE_CONTAXY_DEPLOYMENT_NAME = "CONTAXY_DEPLOYMENT_NAME"
 
 
 class Labels(Enum):
@@ -228,6 +233,7 @@ def map_endpoints_label_to_endpoints(
 def get_default_environment_variables(
     project_id: str,
     deployment_id: str,
+    auth_manager: AuthManager,
     endpoints: Optional[List[str]] = None,
     compute_resources: Optional[DeploymentCompute] = None,
 ) -> Dict[str, str]:
@@ -236,6 +242,7 @@ def get_default_environment_variables(
     Args:
         project_id (str): The project id included in the label list
         deployment_id (str)
+        auth_manager (AuthManager): Auth manager used for creating an access token for the service
         endpoints (List[str]): List of endpoints
         compute_resources: (Optional[DeploymentCompute]): DeploymentCompute information
 
@@ -244,15 +251,28 @@ def get_default_environment_variables(
     """
 
     default_environment_variables = {
-        "CONTAXY_DEPLOYMENT_NAME": deployment_id,
+        _ENV_VARIABLE_CONTAXY_DEPLOYMENT_NAME: deployment_id,
         _ENV_VARIABLE_CONTAXY_BASE_URL: settings.CONTAXY_BASE_URL,
         _ENV_VARIABLE_CONTAXY_API_ENDPOINT: settings.CONTAXY_API_ENDPOINT,
     }
 
+    # TODO: This url is only valid for services but not for jobs
+    service_access_permission = auth_utils.construct_permission(
+        f"/projects/{project_id}/services/{deployment_id}/access/", AccessLevel.READ
+    )
+    service_api_token = auth_manager.create_token(
+        scopes=[service_access_permission],
+        token_type=TokenType.API_TOKEN,
+        description=f"Access token for service {deployment_id}.",
+        token_purpose=TokenPurpose.SERVICE_ACCESS_TOKEN,
+    )
+    default_environment_variables[_ENV_VARIABLE_CONTAXY_API_TOKEN] = service_api_token
+
     if endpoints and len(endpoints) > 0:
         endpoint = endpoints[0]
         if len(endpoints) > 1:
             endpoint = "{endpoint}"
+        # TODO: This url is only valid for services but not for jobs
         default_environment_variables[
             _ENV_VARIABLE_CONTAXY_SERVICE_URL
         ] = f"{settings.CONTAXY_BASE_URL}/projects/{project_id}/services/{deployment_id}/access/{endpoint}"
@@ -324,7 +344,7 @@ def replace_templates(
 def get_template_mapping(
     project_id: Optional[str] = None,
     user_id: Optional[str] = None,
-    service_url: Optional[str] = None,
+    environment: Dict[str, str] = None,
 ) -> Dict[str, str]:
     template_mapping = {}
 
@@ -344,8 +364,9 @@ def get_template_mapping(
     if user_id:
         template_mapping["{env.userId}"] = user_id
 
-    if service_url:
-        template_mapping[f"{{env.{_ENV_VARIABLE_CONTAXY_SERVICE_URL}}}"] = service_url
+    if environment:
+        for env_name, env_value in environment.items():
+            template_mapping[f"{{env.{env_name}}}"] = env_value
 
     return template_mapping
 
